@@ -1,6 +1,6 @@
 summary.PA_result <- function(object,...){
-  cat("\nPA_result object contains estimated attachment function. \n");
-  cat("Number of bins: ", object$G,"\n");
+  cat("\nContaining the estimated attachment function. \n");
+  cat("Number of bins: ", object$g,"\n");
   cat("Estimated attachment exponent:", object$alpha, "\n");
   if (object$ci[1] == "N") {
       cat("No possible confidence interval for the estimated attachment exponent.\n");
