@@ -5,7 +5,7 @@ net  <- generate_net(N = 100, m = 10,prob_m = TRUE, increase = TRUE, log = TRUE,
 
 for (bin in c("FALSE","TRUE")) {
     deg_thresh <- 0
-    net_stats <- get_statistics(net$graph,deg_threshold = deg_thresh, binning = bin, g = 10, net_type = "undirected") 
+    net_stats <- get_statistics(net,deg_threshold = deg_thresh, binning = bin, g = 10) 
             #check stats
     if (sum(net_stats$m_t) != sum(net_stats$sum_m_k))
         stop("wrong at m_t and sum_m_k")
@@ -29,7 +29,7 @@ net$graph[,1] <- temp
 
 for (bin in c("FALSE","TRUE")) {
   deg_thresh <- 0
-  net_stats <- get_statistics(net$graph,deg_threshold = deg_thresh, binning = bin, g = 10, net_type = "undirected") 
+  net_stats <- get_statistics(net,deg_threshold = deg_thresh, binning = bin, g = 10) 
   #check stats
   if (sum(net_stats$m_t) != sum(net_stats$sum_m_k))
     stop("wrong at m_t and sum_m_k")
@@ -48,7 +48,7 @@ net$graph[,1] <- rev(net$graph[,1])
 
 for (bin in c("FALSE","TRUE")) {
   deg_thresh <- 0
-  net_stats <- get_statistics(net$graph,deg_threshold = deg_thresh, binning = bin, g = 10, net_type = "undirected") 
+  net_stats <- get_statistics(net,deg_threshold = deg_thresh, binning = bin, g = 10) 
   #check stats
   if (sum(net_stats$m_t) != sum(net_stats$sum_m_k))
     stop("wrong at m_t and sum_m_k")
@@ -67,7 +67,7 @@ net$graph[,2] <- rev(net$graph[,2])
 
 for (bin in c("FALSE","TRUE")) {
   deg_thresh <- 0
-  net_stats <- get_statistics(net$graph,deg_threshold = deg_thresh, binning = bin, g = 10, net_type = "undirected") 
+  net_stats <- get_statistics(net,deg_threshold = deg_thresh, binning = bin, g = 10) 
   #check stats
   if (sum(net_stats$m_t) != sum(net_stats$sum_m_k))
     stop("wrong at m_t and sum_m_k")
